( cd bin ; rm -rf compress )
( cd bin ; ln -sf /usr/bin/compress compress )
( cd bin ; rm -rf red )
( cd bin ; ln -sf ed red )
( cd sbin ; rm -rf fsck.hpfs )
( cd sbin ; ln -sf /bin/true fsck.hpfs )
( cd sbin ; rm -rf fsck.msdos )
( cd sbin ; ln -sf /bin/true fsck.msdos )
( cd sbin ; rm -rf fsck.reiserfs )
( cd sbin ; ln -sf /bin/true fsck.reiserfs )
( cd sbin ; rm -rf fsck.umsdos )
( cd sbin ; ln -sf /bin/true fsck.umsdos )
( cd sbin ; rm -rf mkfs.msdos )
( cd sbin ; ln -sf mkdosfs mkfs.msdos )
( cd usr/bin ; rm -rf atq )
( cd usr/bin ; ln -sf at atq )
( cd usr/bin ; rm -rf atrm )
( cd usr/bin ; ln -sf at atrm )
( cd usr/bin ; rm -rf awk )
( cd usr/bin ; ln -sf gawk awk )
( cd usr/bin ; rm -rf bash )
( cd usr/bin ; ln -sf /bin/bash bash )
( cd usr/bin ; rm -rf rpm2tgz )
( cd usr/bin ; ln -sf rpm2targz rpm2tgz )
( cd usr/bin ; rm -rf uncompress )
( cd usr/bin ; ln -sf compress uncompress )
( cd usr/doc/dosfstools-2.8/dosfsck ; rm -rf COPYING )
( cd usr/doc/dosfstools-2.8/dosfsck ; ln -sf ../../at-3.1.8/COPYING COPYING )
( cd usr/doc/dosfstools-2.8/mkdosfs ; rm -rf COPYING )
( cd usr/doc/dosfstools-2.8/mkdosfs ; ln -sf ../../at-3.1.8/COPYING COPYING )
( cd usr/doc/gawk-3.0.6 ; rm -rf COPYING )
( cd usr/doc/gawk-3.0.6 ; ln -sf ../at-3.1.8/COPYING COPYING )
( cd usr/doc/indent-2.2.6 ; rm -rf COPYING )
( cd usr/doc/indent-2.2.6 ; ln -sf ../at-3.1.8/COPYING COPYING )
( cd usr/doc/patch-2.5.4 ; rm -rf COPYING )
( cd usr/doc/patch-2.5.4 ; ln -sf ../at-3.1.8/COPYING COPYING )
( cd usr/doc/sed-3.02 ; rm -rf COPYING )
( cd usr/doc/sed-3.02 ; ln -sf ../at-3.1.8/COPYING COPYING )
( cd usr/doc/which-2.12 ; rm -rf COPYING )
( cd usr/doc/which-2.12 ; ln -sf ../at-3.1.8/COPYING COPYING )
( cd usr/lib ; rm -rf makewhatis )
( cd usr/lib ; ln -sf /usr/sbin/makewhatis makewhatis )
( cd usr/man/man1 ; rm -rf atq.1.gz )
( cd usr/man/man1 ; ln -sf at.1.gz atq.1.gz )
( cd usr/man/man1 ; rm -rf atrm.1.gz )
( cd usr/man/man1 ; ln -sf at.1.gz atrm.1.gz )
( cd usr/man/man1 ; rm -rf batch.1.gz )
( cd usr/man/man1 ; ln -sf at.1.gz batch.1.gz )
if [ ! -r var/spool/cron/crontabs/root ]
then
   mv var/spool/cron/crontabs/root.new var/spool/cron/crontabs/root
else
   mv var/spool/cron/crontabs/root.new var/spool/cron/root.crontab.sample
fi
# Install the info files for this package
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/indent.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/sed.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/sharutils.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/time.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/which.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/ed.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/gawk.info.gz 2>/dev/null
fi

# Process the incoming configuration files

if [ ! -f etc/at.deny ]
then
   mv install/conf/etc/at.deny etc/at.deny
else
   if [ "`md5sum install/conf/etc/at.deny | cut -d ' ' -f 1 2>/dev/null`" = "`md5sum etc/at.deny | cut -d ' ' -f 1 2>/dev/null`" ]
   then
      mv install/conf/etc/at.deny etc/at.deny
   else
      rm install/conf/etc/at.deny
   fi
fi

# Make sure the incoming conf directory is gone
rm -rf install/conf
